SystemOrganization addCategory: #ConfigurationOfCoExist!

Object subclass: #ConfigurationOfCoExist
	instanceVariableNames: 'project'
	classVariableNames: 'LastVersionLoad'
	poolDictionaries: ''
	category: 'ConfigurationOfCoExist'!

!ConfigurationOfCoExist commentStamp: '<historical>' prior: 0!
Copy me to create a new configuration or edit and evaluate the following doits.

        "Create configuration class and initial baseline method"

        MetacelloToolBox 
                createBaseline: '1.0-baseline'
                for: 'MyProject'
                repository: 'http://www.example.com/MyProjectRepository'
                requiredProjects: #('Gofer')
                packages: #('MyProject-Core' 'MyProject-Tests')
                dependencies:
                        {('MyProject-Core' -> #('Gofer')).
                         ('MyProject-Tests' -> #('MyProject-Core'))}
                groups:
                        {('default' -> #('Core')).
                        ('Core' -> #('MyProject-Core')).
                        ('Tests' -> #('MyProject-Tests'))}.

	   "create initial development method from the baseline"

         MetacelloToolBox
               createDevelopment: '1.0'
               for: 'MyProject'
                importFromBaseline: '1.0-baseline'
                description: 'initial version'.
!

!ConfigurationOfCoExist class methodsFor: 'development support' stamp: 'mt 7/16/2013 11:10:39.146'!
DevelopmentSupport

"See the methods in the 'development support' category on the class-side of MetacelloBaseConfiguration. Decide what development support methods you would like to use and copy them the the class-side of your configuration."
	<apiDocumentation>
! !

!ConfigurationOfCoExist class methodsFor: 'private' stamp: 'mt 7/16/2013 11:10:39.318'!
baseConfigurationClassIfAbsent: aBlock

	^Smalltalk
		at: #MetacelloBaseConfiguration
		ifAbsent: [ 
			self ensureMetacelloBaseConfiguration.
			Smalltalk at: #MetacelloBaseConfiguration ifAbsent: aBlock ].
! !

!ConfigurationOfCoExist class methodsFor: 'private' stamp: 'mt 7/16/2013 11:10:39.404'!
ensureMetacello

	(self baseConfigurationClassIfAbsent: []) ensureMetacello! !

!ConfigurationOfCoExist class methodsFor: 'private' stamp: 'mt 7/16/2013 11:10:39.489'!
ensureMetacelloBaseConfiguration

	Smalltalk
		at: #MetacelloBaseConfiguration
		ifAbsent: [ 
			| repository version |
			repository := MCHttpRepository location: 'http://seaside.gemstone.com/ss/metacello' user: '' password: ''.
			repository
				versionReaderForFileNamed: 'Metacello-Base-DaleHenrichs.2.mcz'
				do: [ :reader | 
					version := reader version.
					version load.
					version workingCopy repositoryGroup addRepository: repository ] ]! !

!ConfigurationOfCoExist class methodsFor: 'metacello tool support' stamp: 'mt 7/16/2013 11:10:39.576'!
isMetacelloConfig
	"Answer true and the Metacello tools will operate on you"
	
	^true! !

!ConfigurationOfCoExist class methodsFor: 'loading' stamp: 'mt 7/16/2013 11:10:39.661'!
load
	"Load the #stable version defined for this platform. The #stable version is the version that is recommended to be used on this platform."

	"self load"

	<apiDocumentation>
	^(self project version: #stable) load! !

!ConfigurationOfCoExist class methodsFor: 'loading' stamp: 'mt 7/16/2013 11:10:39.746'!
loadBleedingEdge
	"Load the latest versions of the mcz files defined for this project. It is not likely that the #bleedingEdge has been tested."

	"self loadBleedingEdge"

	<apiDocumentation>
	^(self project version: #bleedingEdge) load! !

!ConfigurationOfCoExist class methodsFor: 'loading' stamp: 'mt 7/16/2013 11:10:39.832'!
loadDevelopment
	"Load the #development version defined for this platform. The #development version will change over time and is not expected to be stable."

	"self loadDevelopment"

	<apiDocumentation>
	^(self project version: #development) load! !

!ConfigurationOfCoExist class methodsFor: 'accessing' stamp: 'mt 7/16/2013 11:27:22.247'!
project

	^self new preLoad project! !

!ConfigurationOfCoExist class methodsFor: 'development support' stamp: 'mt 7/16/2013 11:10:39.232'!
validate
	"Check the configuration for Errors, Critical Warnings, and Warnings (see class comment for MetacelloMCVersionValidator for more information). 
	Errors identify specification issues that will result in unexpected behaviour when you load the configuration. 
	Critical Warnings identify specification issues that may result in unexpected behavior when you load the configuration.
	Warnings identify specification issues that are technically correct, but are worth take a look at."

	"self validate"

	<apiDocumentation>
	self ensureMetacello.
	^ ((Smalltalk at: #MetacelloToolBox) validateConfiguration: self debug: #() recurse: false) explore! !

!ConfigurationOfCoExist methodsFor: 'baselines' stamp: 'mt 7/16/2013 14:08:00.497'!
baseline100: spec
	<version: '1.0-basline'>
	
	spec for: #common do: [
		spec blessing: #baseline.
		spec repository: 'http://www.hpi.uni-potsdam.de/hirschfeld/squeaksource/ContiuousVersioning'.
		
		spec project: 'OmniBrowser' with: [
			spec
				className: 'ConfigurationOfOmniBrowser';
				loads: #('Core RB' 'OB-SUnitIntegration' 'OB-Shout');
				repository: 'http://www.squeaksource.com/MetacelloRepository'].
		
		spec project: 'Signals' with: [
			spec
				className: 'ConfigurationOfSignals';
				repository: 'http://www.hpi.uni-potsdam.de/hirschfeld/squeaksource/MetacelloRepository'].

		spec project: 'LateClassBinding' with: [
			spec
				className: 'ConfigurationOfLateClassBinding';
				loads: #('core');
				repository: 'http://www.hpi.uni-potsdam.de/hirschfeld/squeaksource/MetacelloRepository'].

		spec project: 'OB-LateClassBinding' with: [
			spec
				className: 'ConfigurationOfLateClassBinding';
				loads: #('ob');
				repository: 'http://www.hpi.uni-potsdam.de/hirschfeld/squeaksource/MetacelloRepository'].
		
		spec project: 'SwaUtil' with: [
			spec
				className: 'ConfigurationOfSwaUtil';
				repository: 'http://www.hpi.uni-potsdam.de/hirschfeld/squeaksource/MetacelloRepository'].

		spec project: 'Widgets' with: [
			spec
				className: 'ConfigurationOfWidgets';
				loads: #('core');
				repository: 'http://www.hpi.uni-potsdam.de/hirschfeld/squeaksource/MetacelloRepository'].
		
		spec package: 'Icons' with: [
			spec repository: 'http://www.hpi.uni-potsdam.de/hirschfeld/squeaksource/SwaUtilities'].
		
		spec
			package: 'PolySource' with: [spec requires: #('Signals' 'Icons' 'LateClassBinding')];
			package: 'CV' with: [spec
				requires: #('PolySource' 'Widgets' 'Icons' 'OmniBrowser' 'OB-LateClassBinding');
				postLoadDoIt: #postLoad].
			
		spec
			group: 'default' with: #('core');
			group: 'core' with: #('PolySource' 'CV').
		].! !

!ConfigurationOfCoExist methodsFor: 'accessing' stamp: 'mt 7/16/2013 11:10:38.975'!
customProjectAttributes
	 "Edit to return a collection of any custom attributes e.g. for conditional loading: Array with: #'Condition1' with: #'Condition2.
	For more information see: http://code.google.com/p/metacello/wiki/CustomProjectAttrributes"

	^ #().! !

!ConfigurationOfCoExist methodsFor: 'symbolic versions' stamp: 'mt 7/16/2013 14:15:38.544'!
development: spec 
	<symbolicVersion: #development>
	
	spec for: #'common' version: '2.0.0'.! !

!ConfigurationOfCoExist methodsFor: 'pre-/postload' stamp: 'mt 7/16/2013 14:07:09.05'!
postLoad

	(PackageInfo named: #PolySource) packageInfo actualMethodsDo: [:method |
		method methodClass recompile: method selector].

	ClassBuilder recompile: #validateClassName:.! !

!ConfigurationOfCoExist methodsFor: 'pre-/postload' stamp: 'mt 7/16/2013 11:27:03.111'!
preLoad

	| privatePackages loginData |
	privatePackages := Dictionary newFrom: {
		#'PolySource' -> #('http://www.hpi.uni-potsdam.de/hirschfeld/squeaksource/' 'ContiuousVersioning').
		#'CV-TestBed' -> #('http://www.hpi.uni-potsdam.de/hirschfeld/squeaksource/' 'ContiuousVersioning').
		#'CV' -> #('http://www.hpi.uni-potsdam.de/hirschfeld/squeaksource/' 'ContiuousVersioning')}.
	loginData := Dictionary new.
		
	privatePackages keysAndValuesDo: [:packageName :location |
		(MCPackage named: packageName) workingCopy repositoryGroup ifNotNil: [:group |
			(group repositories anySatisfy: [:repo | repo isKindOf: MCHttpRepository]) ifFalse: [
				loginData at: location first ifAbsentPut: [
					(UIManager default request: 'User (Squeaksource @ HPI)') -> (UIManager default requestPassword: 'Password (Squeaksource @ HPI)')].
				group addRepository: (MCHttpRepository
					location: location first, location second
					user: (loginData at: location first) key
					password: (loginData at: location first) value)]]].! !

!ConfigurationOfCoExist methodsFor: 'accessing' stamp: 'mt 7/16/2013 11:10:39.06'!
project

	^ project ifNil: [ | constructor |
		"Bootstrap Metacello if it is not already loaded"
		(self class baseConfigurationClassIfAbsent: []) ensureMetacello.
		"Construct Metacello project"
		project := MetacelloMCProject new projectAttributes: self customProjectAttributes. 
		constructor := (Smalltalk at: #MetacelloVersionConstructor) on: self project: project.
		project loadType: #linear. "change to #atomic if desired"
		project ]! !

!ConfigurationOfCoExist methodsFor: 'symbolic versions' stamp: 'mt 7/16/2013 14:15:46.136'!
stable: spec 
	<symbolicVersion: #stable>
	
	"squeak 4.4"
	spec for: #'squeak4.x' version: '1.0.0'.! !

!ConfigurationOfCoExist methodsFor: 'versions' stamp: 'mt 7/16/2013 14:13:53.223'!
version100: spec
	<version: '1.0.0' imports: #('1.0-baseline')>
	
	spec for: #common do: [
		spec blessing: #release.
		spec author: 'Stephi Platz'.
		
		spec
			project: 'OmniBrowser' with: '1.1.5';
			project: 'Signals' with: '1.0.8';
			project: 'LateClassBinding' with: '1.0.0';
			project: 'OB-LateClassBinding' with: '1.0.0';
			project: 'SwaUtil' with: '1.1.5';
			project: 'Widgets' with: #development.
		
		spec
			package: 'Icons' with: 'Icon-mt.3';
			package: 'PolySource' with: 'PolySource-sp.158';
			package: 'CV' with: 'CV-sp.107'.]! !

!ConfigurationOfCoExist methodsFor: 'versions' stamp: 'mt 7/16/2013 14:15:16.523'!
version200: spec
	<version: '2.0.0' imports: #('1.0-baseline')>
	
	spec for: #common do: [
		spec blessing: #development.
		spec author: 'Stephi Platz'.
		
		spec
			project: 'OmniBrowser' with: #stable;
			project: 'Signals' with: #stable;
			project: 'LateClassBinding' with: #development;
			project: 'OB-LateClassBinding' with: #development;
			project: 'SwaUtil' with: #development;
			project: 'Widgets' with: #development.
		
	"	spec
			package: 'Icons' with: 'Icon-mt.3';
			package: 'PolySource' with: 'PolySource-sp.158';
			package: 'CV' with: 'CV-sp.107'."]! !
